@@ -267,6 +267,20 @@ GgitRemote         *ggit_repository_create_remote     (GgitRepository        *re
                                                        const gchar           *url,
                                                        GError               **error);
 
+gboolean            ggit_repository_remove_remote     (GgitRepository        *repository,
+                                                       const gchar           *name,
+                                                       GError               **error);
+
+gboolean            ggit_repository_set_remote_url    (GgitRepository        *repository,
+                                                       const gchar           *remote,
+                                                       const gchar           *url,
+                                                       GError               **error);
+
+gchar             **ggit_repository_rename_remote     (GgitRepository        *repository,
+                                                       const gchar           *name,
+                                                       const gchar           *new_name,
+                                                       GError               **error);
+
 gchar             **ggit_repository_list_remotes      (GgitRepository        *repository,
                                                        GError               **error);
 
@@ -491,6 +505,18 @@ gboolean            ggit_repository_path_is_ignored    (GgitRepository
                                                         const gchar             *path,
                                                         GError                 **error);
 
+void                ggit_repository_merge              (GgitRepository          *repository,
+                                                        GgitAnnotatedCommit    **their_heads,
+                                                        gsize                   *their_heads_length,
+                                                        GgitMergeOptions        *merge_opts,
+                                                        GgitCheckoutOptions     *checkout_opts,
+                                                        GError                 **error);
+
+GgitOId            *ggit_repository_merge_base         (GgitRepository          *repository,
+                                                        GgitOId                 *oid_one,
+                                                        GgitOId                 *oid_two,
+                                                        GError                 **error);
+
 GgitIndex          *ggit_repository_merge_trees        (GgitRepository          *repository,
                                                         GgitTree                *ancestor_tree,
                                                         GgitTree                *our_tree,
